@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * presets.c
- * Copyright (C) John Stebbins 2008-2018 <stebbins@stebbins>
+ * Copyright (C) John Stebbins 2008-2019 <stebbins@stebbins>
  *
  * presets.c is free software.
  *
@@ -500,7 +500,7 @@ ghb_settings_to_ui(signal_user_data_t *ud, GhbValue *dict)
 }
 
 char*
-preset_get_fullname(hb_preset_index_t *path, const char * sep)
+preset_get_fullname(hb_preset_index_t *path, const char * sep, gboolean escape)
 {
     int                ii;
     GString           *gstr;
@@ -522,7 +522,16 @@ preset_get_fullname(hb_preset_index_t *path, const char * sep)
         if (name != NULL)
         {
             g_string_append(gstr, sep);
-            g_string_append(gstr, name);
+            if (escape)
+            {
+                char * esc = g_markup_escape_text(name, -1);
+                g_string_append(gstr, esc);
+                g_free(esc);
+            }
+            else
+            {
+                g_string_append(gstr, name);
+            }
         }
     }
     free(tmp);
@@ -542,7 +551,7 @@ set_preset_menu_button_label(signal_user_data_t *ud, hb_preset_index_t *path)
 
     dict = hb_preset_get(path);
     type = ghb_dict_get_int(dict, "Type");
-    fullname = preset_get_fullname(path, " <span alpha=\"70%\">></span> ");
+    fullname = preset_get_fullname(path, " <span alpha=\"70%\">></span> ", TRUE);
     label = GTK_LABEL(GHB_WIDGET(ud->builder, "presets_menu_button_label"));
     text = g_strdup_printf("%s%s", type == HB_PRESET_TYPE_CUSTOM ?
                                    "Custom" : "Official", fullname);
@@ -2041,17 +2050,18 @@ preset_export_action_cb(GSimpleAction *action, GVariant *param,
                         signal_user_data_t *ud)
 {
     hb_preset_index_t *path;
-    const gchar       *name;
     GtkWindow         *hb_window;
     GtkWidget         *dialog;
     GtkResponseType    response;
     const gchar       *exportDir;
     gchar             *filename;
     GhbValue          *dict;
+    char              *preset_name;
 
     path = get_selected_path(ud);
     if (path == NULL || path->depth <= 0)
     {
+        const gchar       *name;
         char * new_name;
 
         free(path);
@@ -2071,7 +2081,7 @@ preset_export_action_cb(GSimpleAction *action, GVariant *param,
     {
         return;
     }
-    name = ghb_dict_get_string(dict, "PresetName");
+    preset_name = g_strdup(ghb_dict_get_string(dict, "PresetName"));
 
     hb_window = GTK_WINDOW(GHB_WIDGET(ud->builder, "hb_window"));
     dialog = gtk_file_chooser_dialog_new(_("Export Preset"), hb_window,
@@ -2085,10 +2095,16 @@ preset_export_action_cb(GSimpleAction *action, GVariant *param,
     {
         exportDir = ".";
     }
-    filename = g_strdup_printf("%s.json", name);
+
+    // Clean up preset name for use as a filename.  Removing leading
+    // and trailing whitespace and filename illegal characters.
+    g_strstrip(preset_name);
+    g_strdelimit(preset_name, GHB_UNSAFE_FILENAME_CHARS, '_');
+    filename = g_strdup_printf("%s.json", preset_name);
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), exportDir);
     gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), filename);
     g_free(filename);
+    g_free(preset_name);
 
     response = gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_hide(dialog);
@@ -2170,7 +2186,7 @@ preset_rename_action_cb(GSimpleAction *action, GVariant *param,
         ghb_dict_set_string(ud->settings, "PresetDescription", desc);
         free(desc);
 
-        char * full = preset_get_fullname(path, "/");
+        char * full = preset_get_fullname(path, "/", FALSE);
         ghb_dict_set_string(ud->settings, "PresetFullName", full);
         ghb_dict_set_string(ud->settings, "PresetName", name);
         free(full);
@@ -2810,7 +2826,7 @@ ghb_get_current_preset(signal_user_data_t *ud)
             char *fullname;
 
             preset   = hb_value_dup(preset);
-            fullname = preset_get_fullname(path, "/");
+            fullname = preset_get_fullname(path, "/", FALSE);
             ghb_dict_set_string(preset, "PresetFullName", fullname);
             free(fullname);
         }
@@ -2832,7 +2848,7 @@ presets_list_selection_changed_cb(GtkTreeSelection *selection, signal_user_data_
             !ghb_dict_get_bool(ud->settings, "preset_reload"))
         {
             ghb_preset_to_settings(ud->settings, dict);
-            char *fullname = preset_get_fullname(path, "/");
+            char *fullname = preset_get_fullname(path, "/", FALSE);
             ghb_dict_set_string(ud->settings, "PresetFullName", fullname);
             free(fullname);
             ghb_set_current_title_settings(ud);
