@@ -1,6 +1,6 @@
 /* fifo.c
 
-   Copyright (c) 2003-2018 HandBrake Team
+   Copyright (c) 2003-2019 HandBrake Team
    This file is part of the HandBrake source code
    Homepage: <http://handbrake.fr/>.
    It may be used under the terms of the GNU General Public License v2.
@@ -597,6 +597,79 @@ hb_buffer_t * hb_frame_buffer_init( int pix_fmt, int width, int height )
     return buf;
 }
 
+void hb_frame_buffer_blank_stride(hb_buffer_t * buf)
+{
+    uint8_t * data;
+    int       pp, yy, width, height, stride, height_stride;
+
+    for (pp = 0; pp < 4; pp++)
+    {
+        data          = buf->plane[pp].data;
+        width         = buf->plane[pp].width;
+        height        = buf->plane[pp].height;
+        stride        = buf->plane[pp].stride;
+        height_stride = buf->plane[pp].height_stride;
+
+        if (data != NULL)
+        {
+            // Blank right margin
+            for (yy = 0; yy < height; yy++)
+            {
+                memset(data + yy * stride + width, 0x80, stride - width);
+            }
+            // Blank bottom margin
+            for (yy = height; yy < height_stride; yy++)
+            {
+                memset(data + yy * stride, 0x80, stride);
+            }
+        }
+    }
+}
+
+void hb_frame_buffer_mirror_stride(hb_buffer_t * buf)
+{
+    uint8_t * data;
+    int       pp, ii, yy, width, height, stride, height_stride;
+    int       pos, margin, margin_front, margin_back;
+
+    for (pp = 0; pp < 4; pp++)
+    {
+        data          = buf->plane[pp].data;
+        width         = buf->plane[pp].width;
+        height        = buf->plane[pp].height;
+        stride        = buf->plane[pp].stride;
+        height_stride = buf->plane[pp].height_stride;
+        if (data != NULL)
+        {
+            margin       = stride - width;
+            margin_front = margin / 2;
+            margin_back  = margin - margin_front;
+            for (yy = 0; yy < height; yy++)
+            {
+                // Mirror final row pixels into front of stride region
+                pos = yy * stride + width;
+                for (ii = 0; ii < margin_back; ii++)
+                {
+                    *(data + pos + ii) = *(data + pos - ii - 1);
+                }
+                // Mirror start of next row into end of stride region
+                pos = (yy + 1) * stride - 1;
+                for (ii = 0; ii < margin_front; ii++)
+                {
+                    *(data + pos - ii) = *(data + pos + ii + 1);
+                }
+            }
+            // Mirror bottom rows into height_stride
+            pos = height * stride;
+            for (ii = 0; ii < height_stride - height; ii++)
+            {
+                memcpy(data + pos + ii * stride,
+                       data + pos - ((ii + 1) * stride), stride);
+            }
+        }
+    }
+}
+
 // this routine reallocs a buffer for an uncompressed YUV420 video frame
 // with dimensions width x height.
 void hb_video_buffer_realloc( hb_buffer_t * buf, int width, int height )
